@@ -198,6 +198,10 @@ class Assistant(AssistantBase):
     assistant_ids: List[str] = Field(default_factory=list)
     version_count: Optional[int] = None
     prompt_variables: Optional[List[PromptVariable]] = Field(default=None)
+    categories: List[str] = Field(
+        default_factory=list,
+        description="List of categories for marketplace classification (e.g., 'quality-assurance', 'data-analysis')",
+    )
 
 
 class AssistantRequestBase(AssistantBase):
@@ -220,6 +224,10 @@ class AssistantRequestBase(AssistantBase):
     shared: bool = False
     is_react: bool = False
     is_global: Optional[bool] = False
+    categories: List[str] = Field(
+        default_factory=list,
+        description="List of categories for marketplace classification (e.g., 'quality-assurance', 'data-analysis')",
+    )
     slug: Optional[str] = None
     temperature: Optional[float] = None
     top_p: Optional[float] = None
