@@ -83,7 +83,7 @@ class HistoryItem(BaseModel):
     fileNames: List[str]
     assistantId: Optional[str] = None
     thoughts: Optional[List[Thought]] = Field(default_factory=list)
-    workflowExecutionRef: Optional[str] = None
+    workflowExecutionRef: Optional[Union[str, bool]] = None
     executionId: Optional[str] = None
 
 
@@ -144,7 +144,9 @@ class ConversationCreateRequest(BaseModel):
     initial_assistant_id: Optional[str] = None
     folder: Optional[str] = None
     mcp_server_single_usage: Optional[bool] = False
-    is_workflow: Optional[bool] = None
+    is_workflow_conversation: Optional[bool] = Field(
+        default=None, serialization_alias="is_workflow"
+    )
 
 
 class ConversationDetails(BaseModel):
