@@ -478,3 +478,45 @@ class AssistantService:
             dict,
             json_data=request.model_dump(exclude_none=True),
         )
+
+    def publish(
+        self,
+        assistant_id: str,
+        categories: Optional[List[str]] = None,
+        ignore_recommendations: bool = False,
+    ) -> dict:
+        """Publish an assistant to the marketplace.
+        Args:
+            assistant_id: ID of the assistant to publish
+            categories: List of categories for marketplace classification (e.g., ['quality-assurance'])
+            ignore_recommendations: If True, bypass validation and publish anyway
+        """
+        body = {}
+        if categories:
+            body["categories"] = categories
+        if ignore_recommendations:
+            body["ignore_recommendations"] = ignore_recommendations
+
+        return self._api.post(
+            f"/v1/assistants/{assistant_id}/marketplace/publish",
+            dict,
+            json_data=body if body else None,
+        )
+
+    def unpublish(self, assistant_id: str) -> dict:
+        """Unpublish an assistant from the marketplace.
+        Args:
+            assistant_id: ID of the assistant to publish
+        """
+        return self._api.post(
+            f"/v1/assistants/{assistant_id}/marketplace/unpublish", dict
+        )
+
+    def marketplace_validate(self, assistant_id: str) -> dict:
+        """Validate an assistant before publishing to the marketplace.
+        Args:
+            assistant_id: ID of the assistant to validate
+        """
+        return self._api.post(
+            f"/v1/assistants/{assistant_id}/marketplace/publish/validate", dict
+        )
